@@ -47,15 +47,12 @@ gtr_about_dialog (GtrWindow *window)
   static const gchar *authors[] = {
     N_("Current Maintainers"),
     "------------------------",
-    "Seán de Búrca <leftmostcat@gmail.com>",
-    "",
-    N_("Current Developers"),
-    "------------------------",
-    "Seán de Búrca <leftmostcat@gmail.com>",
-    "Ignacio Casal Quinteiro <icq@gnome.org>",
+    "Daniel Garcia Moreno <danigm@gnome.org>",
     "",
     N_("Previous Developers"),
     "------------------------",
+    "Seán de Búrca <leftmostcat@gmail.com>",
+    "Ignacio Casal Quinteiro <icq@gnome.org>",
     "Pablo Sanxiao <psanxiao@gnome.org>",
     "Fatih Demir <kabalak@kabalak.net> (Founder)",
     "Ross Golder <ross@golder.org>",
@@ -76,6 +73,7 @@ gtr_about_dialog (GtrWindow *window)
     NULL
   };
   static const gchar *documenters[] = {
+    "GNOME Documentation Project",
     "Abel Cheung <deaddog@deaddog.org>",
     "Emese Kovacs <emese@gnome.hu>",
     "Pablo Sanxiao <psanxiao@gnome.org>",
@@ -89,21 +87,13 @@ gtr_about_dialog (GtrWindow *window)
   static const gchar comments[] =
     N_("Translation file editing suite for localization of applications and libraries.");
 
-  GdkPixbuf *logo;
-  gchar *logo_file;
-
-  logo_file = g_build_filename (gtr_dirs_get_gtr_pixmaps_dir (),
-                                "gtranslator-logo.png", NULL);
-  logo = gdk_pixbuf_new_from_file (logo_file, NULL);
-  g_free (logo_file);
-
   gtk_show_about_dialog (GTK_WINDOW (window),
                          "comments", _(comments),
                          "authors", authors,
                          "copyright", copyright,
                          "license-type", GTK_LICENSE_GPL_3_0,
                          "documenters", documenters,
-                         "logo", logo, "title", _("About Gtranslator"),
+                         "logo-icon-name", PACKAGE_APPID,
                          /*
                           * Note to translators: put here your name and email so it will show
                           * up in the "about" box
@@ -111,9 +101,7 @@ gtr_about_dialog (GtrWindow *window)
                          "translator-credits", _("translator-credits"),
                          "version", PACKAGE_VERSION,
                          "website", PACKAGE_URL,
-                         "website-label", _("Gtranslator Web Site"),
+                         "website-label", _("Translation Editor Web Site"),
                          NULL);
 
-  if (logo)
-    g_object_unref (logo);
 }
