@@ -75,10 +75,10 @@ gtr_dirs_init ()
 #endif /* !OS_OSX */
   if (gtr_data_dir == NULL)
     {
-      gtr_data_dir = g_build_filename (DATADIR, "gtranslator", NULL);
-      gtr_help_dir = g_build_filename (DATADIR, "gnome", "help", NULL);
-      gtr_locale_dir = g_build_filename (DATADIR, "locale", NULL);
-      gtr_lib_dir = g_build_filename (LIBDIR, "gtranslator", NULL);
+      gtr_data_dir = g_build_filename (PACKAGE_DATADIR, "gtranslator", NULL);
+      gtr_help_dir = g_build_filename (PACKAGE_HELPDIR, "gnome", "help", NULL);
+      gtr_locale_dir = g_build_filename (PACKAGE_LOCALEDIR, "locale", NULL);
+      gtr_lib_dir = g_build_filename (PACKAGE_LIBDIR, "gtranslator", NULL);
     }
 #endif /* !G_OS_WIN32 */
 
